+++
title = "Publish date set using SCHEDULED"
publishDate = 2018-01-26T00:00:00+00:00
tags = ["dates", "publishdate", "scheduled"]
draft = false
+++

If a subtree has the `SCHEDULED` [Special Property](https://orgmode.org/manual/Special-properties.html) set, set the
`publishdate` front-matter to the scheduled date.

By default, `C-c C-s` in Org adds the `SCHEDULED` property to the
current subtree.
